multidim.covertree.CoverLevel.find_entropy — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverLevel.find_entropy

`CoverLevel.` `find_entropy`(adult)

  Compute the entropy of the labelled children on an adult. Store it in self.entropy[adults].

  This is only used by `multidim.models.CDER`

  Parameters: | adult : int index of adult to compute.
  Returns: | self.entropy[adult]

#### Previous topic

multidim.covertree.CoverLevel.cleanup

#### Next topic

multidim.covertree.CoverLevel.find_label_weights